@@ -218,7 +218,7 @@ class factory implements \phpbb\textformatter\cache_interface
 		{
 			$configurator->urlConfig->disallowScheme($scheme);
 		}
-		foreach (explode(',', $this->config['allowed_schemes_links']) as $scheme)
+		foreach (array_filter(explode(',', $this->config['allowed_schemes_links'])) as $scheme)
 		{
 			$configurator->urlConfig->allowScheme(trim($scheme));
 		}
@@ -273,8 +273,6 @@ class factory implements \phpbb\textformatter\cache_interface
 			->add('#imageurl', __NAMESPACE__ . '\\parser::filter_img_url')
 			->addParameterByName('urlConfig')
 			->addParameterByName('logger')
-			->addParameterByName('max_img_height')
-			->addParameterByName('max_img_width')
 			->markAsSafeAsURL()
 			->setJS('UrlFilter.filter');
 
@@ -470,11 +468,17 @@ class factory implements \phpbb\textformatter\cache_interface
 		$tag->attributes->add('text');
 		$tag->template = '<xsl:value-of select="@text"/>';
 
+		$board_url = generate_board_url() . '/';
 		$tag->filterChain
 			->add(array($this->link_helper, 'truncate_local_url'))
 			->resetParameters()
 			->addParameterByName('tag')
-			->addParameterByValue(generate_board_url() . '/');
+			->addParameterByValue($board_url);
+		$tag->filterChain
+			->add(array($this->link_helper, 'truncate_local_url'))
+			->resetParameters()
+			->addParameterByName('tag')
+			->addParameterByValue(preg_replace('(^\\w+:)', '', $board_url));
 		$tag->filterChain
 			->add(array($this->link_helper, 'truncate_text'))
 			->resetParameters()
