@@ -391,7 +391,6 @@ abstract class nestedset implements \phpbb\tree\tree_interface
 			throw new \OutOfBoundsException($this->message_prefix . 'INVALID_PARENT');
 		}
 
-		$diff = sizeof($move_items) * 2;
 		$sql_exclude_moved_items = $this->db->sql_in_set($this->column_item_id, $move_items, true);
 
 		$this->db->sql_transaction('begin');
@@ -490,7 +489,6 @@ abstract class nestedset implements \phpbb\tree\tree_interface
 			throw new \OutOfBoundsException($this->message_prefix . 'INVALID_PARENT');
 		}
 
-		$diff = sizeof($move_items) * 2;
 		$sql_exclude_moved_items = $this->db->sql_in_set($this->column_item_id, $move_items, true);
 
 		$this->db->sql_transaction('begin');
@@ -535,7 +533,7 @@ abstract class nestedset implements \phpbb\tree\tree_interface
 			$row = $this->db->sql_fetchrow($result);
 			$this->db->sql_freeresult($result);
 
-			$diff = ' + ' . ($row[$this->column_right_id] - (int) $item[$this->column_left_id] + 1);
+			$diff = ' + ' . ((int) $row[$this->column_right_id] - (int) $item[$this->column_left_id] + 1);
 		}
 
 		$sql = 'UPDATE ' . $this->table_name . '
@@ -708,7 +706,7 @@ abstract class nestedset implements \phpbb\tree\tree_interface
 	{
 		$acquired_new_lock = $this->acquire_lock();
 
-		$diff = sizeof($subset_items) * 2;
+		$diff = count($subset_items) * 2;
 		$sql_subset_items = $this->db->sql_in_set($this->column_item_id, $subset_items);
 		$sql_not_subset_items = $this->db->sql_in_set($this->column_item_id, $subset_items, true);
 
@@ -748,7 +746,7 @@ abstract class nestedset implements \phpbb\tree\tree_interface
 	*/
 	protected function prepare_adding_subset(array $subset_items, array $new_parent)
 	{
-		$diff = sizeof($subset_items) * 2;
+		$diff = count($subset_items) * 2;
 		$sql_not_subset_items = $this->db->sql_in_set($this->column_item_id, $subset_items, true);
 
 		$set_left_id = $this->db->sql_case($this->column_left_id . ' > ' . (int) $new_parent[$this->column_right_id], $this->column_left_id . ' + ' . $diff, $this->column_left_id);
@@ -837,7 +835,10 @@ abstract class nestedset implements \phpbb\tree\tree_interface
 				' . $this->get_sql_where('AND') . '
 			ORDER BY ' . $this->column_left_id . ', ' . $this->column_item_id . ' ASC';
 		$result = $this->db->sql_query($sql);
-		while ($row = $this->db->sql_fetchrow($result))
+		$rows = $this->db->sql_fetchrowset($result);
+		$this->db->sql_freeresult($result);
+
+		foreach ($rows as $row)
 		{
 			// First we update the left_id for this module
 			if ($row[$this->column_left_id] != $new_id)
@@ -862,7 +863,6 @@ abstract class nestedset implements \phpbb\tree\tree_interface
 			}
 			$new_id++;
 		}
-		$this->db->sql_freeresult($result);
 
 		if ($acquired_new_lock)
 		{
